import { BadgeProps } from './badges.types';
import { bool, number, string } from 'prop-types';
import React, { forwardRef } from 'react';

const Badge = forwardRef<SVGSVGElement, BadgeProps>(function Badge(
    { disableValue = false, ...props },
    ref,
) {
    const digitLength = props.children
            ? 16 + (props.children.length - 1) * 6
            : 6,
        disableValueClassName =
            disableValue || (!props.children ?? true) ? 'disable-value' : '';

    return (
        <svg
            {...props}
            className={`m3 m3-badge ${'' ?? props.className}${disableValueClassName}`.trimEnd()}
            ref={ref}
            width={`${digitLength}px`}
        >
            {props.children && (
                <text x={'50%'} y={'50%'}>
                    {props.children}
                </text>
            )}
        </svg>
    );
});

Badge.propTypes = {
    children: number,
    className: string,
    disableValue: bool,
};

export { Badge };
