import { IconProps } from './icon.types';
import { bool, number, string } from 'prop-types';
import React, { ForwardedRef, forwardRef } from 'react';

const Icon = forwardRef(function Icon(
    {
        grade = 0,
        weight = 500,
        svgSize = 20,
        fill = false,
        iconSize = 20,
        opticalSize = 24,
        type = 'outlined',
        ...props
    }: IconProps,
    ref: ForwardedRef<any>,
) {
    const fontVariation = {
        fontVariationSettings: `'FILL' ${fill ? 1 : 0}, 'wght' ${weight}, 'GRAD' ${grade}, 'optz' ${opticalSize}`,
    };

    return (
        <svg
            {...props}
            className={`m3 m3-svg-icon ${props.className ?? ''}`.trim()}
            height={svgSize}
            ref={ref}
            width={svgSize}
        >
            <text
                className={`m3-${type[0].toUpperCase() + type.slice(1)} m3-size-${iconSize}px`}
                style={fontVariation}
                x={'50%'}
                y={'50%'}
            >
                {props.children ?? 'add_circle'}
            </text>
        </svg>
    );
});

Icon.propTypes = {
    fill: bool,
    type: string,
    grade: number,
    weight: number,
    svgSize: number,
    iconSize: number,
    children: string,
    opticalSize: number,
};

export { Icon };
